@@ -4,7 +4,7 @@
 ;;
 ;;   Copyright (C) 2007 Kiyoka Nishiyama
 ;;
-;;     $Date: 2007-04-11 23:14:37 +0900 (Wed, 11 Apr 2007) $
+;;     $Date: 2007-09-16 11:58:36 +0900 (日, 16  9月 2007) $
 ;;
 ;; This file is part of Predoc
 ;;
@@ -28,6 +28,11 @@
 ;;
 ;;
 ;; ChangeLog:
+;;   [0.9.4]
+;;     1. Fixed some bugs.
+;;     2. Added predoc-open-alink() function ( and bind to C-m key )
+;;     3. Supported "http://host/path/of/contents... " string convert into `a' tag. ( necessary to install emacs-w3m )
+;;
 ;;   [0.9.3]
 ;;     1. Added costomize variable `predoc-curl-program'
 ;;     2. Added predoc-open-alink() function ( and bind to '[return]' key )
@@ -50,7 +55,7 @@
 ;;
 (require 'sgml-mode)
 
-(defconst predoc-version "0.9.3")
+(defconst predoc-version "0.9.4")
 
 (defconst predoc-alink-face  'link)
 (defconst predoc-entity-face 'highlight)
@@ -400,9 +405,10 @@ Buffer string between BEG and END are replaced with URL."
 		    predoc-image-prefix-list
 		    "\\|")
 		   "\\)"))
+	  (_url-pattern
+	   "\\(http://[^\t ]+\\|.+html?\\)")
 	  (_url_file-pattern
 	   "\\(http://[^\t ]+\\|.+html?\\)[\t ]+\\([^\t ]+\\)"))
-
       (let ((cur    (point))
 	    (str    (buffer-substring-no-properties (point) (point-at-eol))))
 	(cond
@@ -462,7 +468,17 @@ Buffer string between BEG and END are replaced with URL."
 	    (delete-region (match-beginning 1) (match-end 2))
 	    (goto-char (match-beginning 1))
 	    (insert (format "<a href=\"%s\" />%s</a>" url str))))
-	 ;; No match
+	 ;; http://host/path/of/contents...
+	 ((string-match      (concat "^" _url-pattern) str)
+	  (re-search-forward             _url-pattern (point-at-eol) t)
+	  (if (boundp 'w3m-version)	  
+	      (let* ((url (match-string 1))
+		     (title (or (w3m-arrived-title url)
+				"NoTitle")))
+		(delete-region (match-beginning 1) (match-end 1))
+		(goto-char (match-beginning 1))
+		(insert (format "<a href=\"%s\" />%s</a>" url title)))
+	    (message "Predoc: Please install emacs-w3m.")))
 	 (t
 	  (message "Predoc: <a> link format is URL_or_FILENAME  STRING' . "))))))
 
@@ -482,9 +498,16 @@ Buffer string between BEG and END are replaced with URL."
 	(split-string
 	 (buffer-substring-no-properties (point-min) (point-max)))))
     
+    (defun prefix-check (line)
+      (not
+       (notany
+	(lambda (_prefix)
+	  (string-match (concat _prefix "$") line))
+	predoc-image-prefix-list)))
+
     (mapcar
      (lambda (x)
-       (when (string-match "^./" x)
+       (when (prefix-check x)
 	 (insert
 	  (format "<img src=\"%s\" width=\"%d\"/> " x predoc-insert-image-size))))
      (search-image-files)))
@@ -501,9 +524,10 @@ Buffer string between BEG and END are replaced with URL."
     (local-set-key "\C-c\C-c" 'predoc-modify-wysiwyg-object)
     (local-set-key "\C-cl"    'predoc-insert-images)
     (local-set-key [return]   'predoc-open-alink)
+    (local-set-key "\C-m"     'predoc-open-alink)
     (setq mode-name "Predoc")))
 
 (add-hook 'sgml-mode-hook            'predoc-mode-hookfunc)
 
 (provide 'predoc)
-;; predoc.el ends here
+;; predoc-mode.el ends here
